.. _backend:

*******
Backend
*******

Backend Base
============

.. automodule:: designate.backend.base
    :members:
    :undoc-members:
    :show-inheritance:

Backend Bind9
=============

.. automodule:: designate.backend.impl_bind9
    :members:
    :undoc-members:
    :show-inheritance:

Backend Designate
=================

.. automodule:: designate.backend.impl_designate
    :members:
    :undoc-members:
    :show-inheritance:

Backend Dynect
==============

.. automodule:: designate.backend.impl_dynect
    :members:
    :undoc-members:
    :show-inheritance:

Backend Infoblox
================

.. automodule:: designate.backend.impl_infoblox
    :members:
    :undoc-members:
    :show-inheritance:

Backend Nsd4
============

.. automodule:: designate.backend.impl_nsd4
    :members:
    :undoc-members:
    :show-inheritance:

Backend Fake
============

.. automodule:: designate.backend.impl_fake
    :members:
    :undoc-members:
    :show-inheritance:

Backend PowerDNS 4
==================

.. automodule:: designate.backend.impl_pdns4
    :members:
    :undoc-members:
    :show-inheritance:
